@@ -8,5 +8,5 @@ def use_cassette(*args, **kwargs):
     return VCR(
         cassette_library_dir = os.path.join(os.path.dirname(__file__), 'cassettes'),
         match_on = ['url', 'method', 'headers', 'body'],
-        record_mode = 'new_episodes',
+        record_mode = 'none',
     ).use_cassette(*args, **kwargs)
